@@ -5,6 +5,8 @@ from typing import List, Union
 
 from pydantic import BaseModel, validator
 
+from easyeda2kicad.easyeda.svg_path_parser import parse_svg_path
+
 
 class EasyedaPinType(Enum):
     unspecified = 0
@@ -142,12 +144,68 @@ class EeSymbolRectangle(BaseModel):
 
 # ---------------- CIRCLE ----------------
 class EeSymbolCircle(BaseModel):
-    ...  # TODO
+    center_x: float
+    center_y: float
+    radius: float
+    stroke_color: str
+    stroke_width: str
+    stroke_style: str
+    fill_color: bool
+    id: str
+    is_locked: bool
+
+    @validator("is_locked", pre=True)
+    def empty_str_lock(cls, field: str) -> str:
+        return field or False
+
+    @validator("fill_color", pre=True)
+    def parse_background_filling(cls, fill_color: str) -> str:
+        return bool(fill_color and fill_color.lower() != "none")
 
 
 # ---------------- ARC ----------------
 class EeSymbolArc(BaseModel):
-    ...  # TODO
+    path: list
+    helper_dots: str
+    stroke_color: str
+    stroke_width: str
+    stroke_style: str
+    fill_color: bool
+    id: str
+    is_locked: bool
+
+    @validator("is_locked", pre=True)
+    def empty_str_lock(cls, field: str) -> str:
+        return field or False
+
+    @validator("fill_color", pre=True)
+    def parse_background_filling(cls, fill_color: str) -> str:
+        return bool(fill_color and fill_color.lower() != "none")
+
+    @validator("path", pre=True)
+    def convert_svg_path(cls, path: str) -> list:
+        return parse_svg_path(svg_path=path)
+
+
+class EeSymbolEllipse(BaseModel):
+    center_x: float
+    center_y: float
+    radius_x: float
+    radius_y: float
+    stroke_color: str
+    stroke_width: str
+    stroke_style: str
+    fill_color: bool
+    id: str
+    is_locked: bool
+
+    @validator("is_locked", pre=True)
+    def empty_str_lock(cls, field: str) -> str:
+        return field or False
+
+    @validator("fill_color", pre=True)
+    def parse_background_filling(cls, fill_color: str) -> str:
+        return bool(fill_color and fill_color.lower() != "none")
 
 
 # ---------------- POLYLINE ----------------
@@ -156,7 +214,7 @@ class EeSymbolPolyline(BaseModel):
     stroke_color: str
     stroke_width: str
     stroke_style: str
-    fill_color: str
+    fill_color: bool
     id: str
     is_locked: bool
 
@@ -164,6 +222,10 @@ class EeSymbolPolyline(BaseModel):
     def empty_str_lock(cls, field: str) -> str:
         return field or False
 
+    @validator("fill_color", pre=True)
+    def parse_background_filling(cls, fill_color: str) -> str:
+        return bool(fill_color and fill_color.lower() != "none")
+
 
 # ---------------- POLYGON ----------------
 class EeSymbolPolygon(EeSymbolPolyline):
@@ -179,7 +241,7 @@ class EeSymbolPath(BaseModel):
     stroke_color: str
     stroke_width: str
     stroke_style: str
-    fill_color: str
+    fill_color: bool
     id: str
     is_locked: bool
 
@@ -187,28 +249,15 @@ class EeSymbolPath(BaseModel):
     def empty_str_lock(cls, field: str) -> str:
         return field or False
 
+    @validator("fill_color", pre=True)
+    def parse_background_filling(cls, fill_color: str) -> str:
+        return bool(fill_color and fill_color.lower() != "none")
+
     # @validator("paths", pre=True)
     # def clean_svg_path(cls, paths:str):
     #     return paths.replace("M", "").replace("C","")
 
 
-class EeSymbolEllipse(BaseModel):
-    center_x: float
-    center_y: float
-    radius_x: float
-    radius_y: float
-    stroke_color: str
-    stroke_width: str
-    stroke_style: str
-    fill_color: str
-    id: str
-    is_locked: bool
-
-    @validator("is_locked", pre=True)
-    def empty_str_lock(cls, field: str) -> str:
-        return field or False
-
-
 # ---------------- SYMBOL ----------------
 @dataclass
 class EeSymbolInfo:
@@ -227,6 +276,9 @@ class EeSymbol:
     bbox: EeSymbolBbox
     pins: List[EeSymbolPin] = field(default_factory=list)
     rectangles: List[EeSymbolRectangle] = field(default_factory=list)
+    circles: List[EeSymbolCircle] = field(default_factory=list)
+    arcs: List[EeSymbolArc] = field(default_factory=list)
+    ellipses: List[EeSymbolEllipse] = field(default_factory=list)
     polylines: List[EeSymbolPolyline] = field(default_factory=list)
     polygons: List[EeSymbolPolygon] = field(default_factory=list)
     paths: List[EeSymbolPath] = field(default_factory=list)
@@ -428,7 +480,7 @@ class Ee3dModelBase(BaseModel):
     def convert_to_mm(self) -> None:
         self.x = convert_to_mm(self.x)
         self.y = convert_to_mm(self.y)
-        # self.z = convert_to_mm(self.z)
+        self.z = convert_to_mm(self.z)
 
 
 @dataclass
